@@ -1,7 +1,20 @@
 """
-Pythonic Interface to EBUS Daemon (ebusd).
+Pythonic Interface to EBUS Daemon (EBUSD_).
 
-:class:`Ebus` represents one connection to a EBUSD instance.
+Overview
+========
+
+* :any:`Ebus`: the EBUS handle, using one :any:`Connection` to an EBUSD instance.
+  One EBUSD server can handle multiple :any:`Ebus` instances.
+* :any:`MsgDef`: Message Definition containing multiple Field Defintions :any:`FieldDef`.
+  A Virtual Field Definition :any:`VirtFieldDef` is a calculated value based on other fields.
+* :any:`MsgDefs`: is a container for message definitions (:any:`MsgDef`).
+* :any:`types`: contains the type engine, which allows the simple decode and
+  encode of EBUSD values to/from python values.
+
+All other classes and methods are just helper.
+
+.. _EBUSD: https://github.com/john30/ebusd
 """
 try:
     import importlib.metadata as importlib_metadata
@@ -21,14 +34,11 @@ from .const import OK  # noqa
 from .ebus import Ebus  # noqa
 from .icon import get_icon  # noqa
 from .msg import BrokenMsg  # noqa
-from .msg import Error  # noqa
 from .msg import Field  # noqa
 from .msg import Msg  # noqa
-from .msgdecoder import MsgDecoder  # noqa
 from .msgdecoder import UnknownMsgError  # noqa
 from .msgdef import FieldDef  # noqa
 from .msgdef import MsgDef  # noqa
 from .msgdef import VirtFieldDef  # noqa
 from .msgdef import resolve_prio  # noqa
-from .msgdefdecoder import decode_msgdef  # noqa
 from .msgdefs import MsgDefs  # noqa
