@@ -79,6 +79,6 @@ def print_msg(msg, skipbroken=False):
             unitvalue = field.unitvalue
             if unitvalue is None:
                 unitvalue = ""
-            print(f"{field.ident:<40s} {field.fielddef.msgdef.type_} {unitvalue!s:<20s}{details}")
+            print(f"{field.ident:<40s} {field.fielddef.msgdef.access} {unitvalue!s:<20s}{details}")
     elif not skipbroken:
         _LOGGER.error(f"{msg.msgdef.ident}: {msg.error}")
