@@ -33,13 +33,13 @@ async def _main(args):
     print(f"Listing {msgdefs.summary()}")
     for msgdef in msgdefs:
         for fielddef in msgdef.children:
-            details = repr(fielddef.type_)
+            details = fielddef.type_.comment
             if fielddef.comment:
                 details += f" [{fielddef.comment}]"
             if args.name_only:
                 print(fielddef.ident)
             else:
-                print(f"{fielddef.ident:<40s} {msgdef.type_} {details}")
+                print(f"{fielddef.ident:<40s} {msgdef.access} {details}")
 
 
 def _parse_type(type_):
