@@ -2,6 +2,7 @@
 import asyncio
 import logging
 
+from .const import DEFAULT_HOST, DEFAULT_PORT, DEFAULT_TIMEOUT
 from .util import repr_
 
 _LOGGER = logging.getLogger(__name__)
@@ -17,7 +18,7 @@ class Connection:
         autoconnect (bool): Automatically connect and re-connect
     """
 
-    def __init__(self, host="127.0.0.1", port=8888, autoconnect=False, timeout=None):
+    def __init__(self, host=DEFAULT_HOST, port=DEFAULT_PORT, autoconnect=False, timeout=DEFAULT_TIMEOUT):
         self._host = host
         self._port = port
         self._autoconnect = autoconnect
@@ -28,10 +29,10 @@ class Connection:
         return repr_(
             self,
             kwargs=(
-                ("host", self.host, "127.0.0.1"),
-                ("port", self.port, 8888),
+                ("host", self.host, DEFAULT_HOST),
+                ("port", self.port, DEFAULT_PORT),
                 ("autoconnect", self.autoconnect, False),
-                ("timeout", self.timeout, None),
+                ("timeout", self.timeout, DEFAULT_TIMEOUT),
             ),
         )
 
@@ -60,7 +61,7 @@ class Connection:
         Establish connection (required before first communication).
 
         Raises:
-            IOError: If connection cannot be established
+            ConnectionRefusedError: If connection cannot be established
         """
         _LOGGER.debug("connect()")
         self._reader, self._writer = await self._async_timedout(asyncio.open_connection(self._host, self._port))
@@ -82,14 +83,18 @@ class Connection:
         Return `True` if connection is established.
 
         This does not check if the connection is still usable.
+
+        Returns:
+            bool
         """
         return self._writer is not None and not self._writer.is_closing()
 
     async def async_write(self, message):
         """
-        Send `message`.
+        Send TCP `message` to EBUSD.
 
         Raises:
+            ConnectionRefusedError: If connection cannot be established
             ConnectionError: If not connected (`autoconnect==False`)
         """
         _LOGGER.debug(f"write({message!r})")
@@ -97,7 +102,7 @@ class Connection:
         await self._async_write(message)
 
     async def async_request(self, cmd, *args, **kwargs):
-        """Assemble request, send and receive response."""
+        """Assemble request starting with `cmd` and position `args` and keywords `kwargs'."""
         parts = [cmd]
         parts += [f"-{option} {value}" for option, value in kwargs.items() if value is not None]
         parts += [str(arg) for arg in args]
@@ -108,11 +113,16 @@ class Connection:
 
     async def async_read(self, infinite=False, check=True):
         """
-        Receive lines until an empty one.
+        Receive lines until an empty one (`infinite==False`) or infinitly (`infinite==True`).
+
+        Yields:
+            str: line read
 
         Raises:
-            IOError: If connection is broken or cannot be established (`autoconnect==True`)
+            ConnectionRefusedError: If connection cannot be established
             ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed (`check==True`)
+            EbusdShutdown: On EBUSD shutdown.
         """
         _LOGGER.debug(f"read(infinite={infinite!r}, check={check!r})")
         await self._async_ensure_connection()
@@ -126,7 +136,16 @@ class Connection:
         """
         Receive command response.
 
-        Read command response line and one empty line.
+        Read one line as command response and one empty line.
+
+        Returns:
+            str: response
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed (`check==True`) or trailing data.
+            EbusdShutdown: On EBUSD shutdown.
         """
         _LOGGER.debug(f"readresp(check={check!r})")
         await self._async_ensure_connection()
@@ -170,7 +189,7 @@ class Connection:
 
 class CommandError(RuntimeError):
 
-    """Command Error raised in case of EBUSD error."""
+    """Command Error raised in case of EBUSD error, typically if the response starts with `ERR:`"""
 
 
 class EbusdShutdown(ConnectionError):
