@@ -6,7 +6,7 @@ class _NotAvailable:
     """Not Available."""
 
     def __str__(self):
-        return "Not Available"
+        return "NA"
 
     def __repr__(self):
         return "NA"
@@ -15,3 +15,9 @@ class _NotAvailable:
 OK = "ok"
 AUTO = "A"
 NA = _NotAvailable()
+
+DEFAULT_HOST = "127.0.0.1"
+DEFAULT_PORT = 8888
+DEFAULT_TIMEOUT = 10
+DEFAULT_SCANINTERVAL = 10
+DEFAULT_SCANS = 3
