@@ -4,7 +4,7 @@ import collections
 import logging
 
 from .connection import CommandError, Connection
-from .const import OK
+from .const import DEFAULT_HOST, DEFAULT_PORT, DEFAULT_SCANINTERVAL, DEFAULT_SCANS, DEFAULT_TIMEOUT, OK
 from .msg import BrokenMsg, filter_msg
 from .msgdecoder import MsgDecoder, UnknownMsgError
 from .msgdef import resolve_prio
@@ -21,25 +21,35 @@ class Ebus:
     """
     Pythonic EBUS Representation.
 
-    This instance connects to an EBUSD instance and allows to read, write or monitor.
+    The EBUS handle, using one :any:`Connection` to an EBUSD instance.
+    One EBUSD server can handle multiple :any:`Ebus` instances.
     """
 
-    def __init__(self, host, port, timeout=10, scaninterval=10, scans=3, msgdefs=None):
+    def __init__(
+        self,
+        host=DEFAULT_HOST,
+        port=DEFAULT_PORT,
+        timeout=DEFAULT_TIMEOUT,
+        scaninterval=DEFAULT_SCANINTERVAL,
+        scans=DEFAULT_SCANS,
+        msgdefs=None,
+    ):
         self.connection = Connection(host=host, port=port, autoconnect=True, timeout=timeout)
         self.scaninterval = scaninterval
         self.scans = scans
-        self.msgdefcodes = []
+        self._msgdefcodes = []
         self.msgdecoder = MsgDecoder(msgdefs or MsgDefs())
         _LOGGER.info(f"{self}")
 
     def __repr__(self):
         return repr_(
             self,
-            args=(self.connection.host, self.connection.port),
             kwargs=(
-                ("timeout", self.timeout, 10),
-                ("scaninterval", self.scaninterval, 10),
-                ("scans", self.scans, 3),
+                ("host", self.host, DEFAULT_HOST),
+                ("port", self.port, DEFAULT_PORT),
+                ("timeout", self.timeout, DEFAULT_TIMEOUT),
+                ("scaninterval", self.scaninterval, DEFAULT_SCANINTERVAL),
+                ("scans", self.scans, DEFAULT_SCANS),
             ),
         )
 
@@ -63,9 +73,25 @@ class Ebus:
         """Timeout."""
         return self.connection.timeout
 
+    @property
+    def msgdefcodes(self):
+        """
+        List with raw EBUSD Message Defintions Codes.
+
+        This property is writeable.
+        """
+        return self._msgdefcodes
+
+    @msgdefcodes.setter
+    def msgdefcodes(self, msgdefcodes):
+        self._msgdefcodes = msgdefcodes
+
     @property
     def msgdefs(self):
-        """Message Defintions."""
+        """
+        Message Defintions :any:`MsgDefs`.
+
+        This property is writeable.."""
         return self.msgdecoder.msgdefs
 
     @msgdefs.setter
@@ -83,7 +109,15 @@ class Ebus:
         )
 
     async def async_wait_scancompleted(self):
-        """Wait until scan is completed."""
+        """
+        Wait until EBUSD device scan is completed.
+
+        EBUSD scans the bus infrastructure at startup be default.
+        Devices and messages are detected during this time.
+        This method waits until no new message are found.
+        It checks every `scaninterval` seconds.
+        The number of messages has to be stable for `scans` times.
+        """
         cnts = []
         while True:
             await self.connection.async_request(_CMD_FINDMSGDEFS)
@@ -98,13 +132,13 @@ class Ebus:
         """
         Load Message Definitions from EBUSD.
 
-        Alias for `load_msgdefcodes` and `decode_msgdefcodes`.
+        Alias for :any:`async_load_msgdefcodes` and :any:`decode_msgdefcodes`.
         """
         await self.async_load_msgdefcodes()
         self.decode_msgdefcodes()
 
     async def async_load_msgdefcodes(self):
-        """Load EBUS Message Definition Codes."""
+        """Load EBUS Message Definition Codes from EBUSD and store to :any:`msgdefcodes`."""
         _LOGGER.info("load_msgdefcodes()")
         self.msgdefcodes = msgdefcodes = []
         await self.connection.async_request(_CMD_FINDMSGDEFS)
@@ -137,14 +171,43 @@ class Ebus:
         """
         Read Message.
 
+        Args:
+            msgdef (MsgDef): Message Definition
+
+        Keyword Args:
+            ttl (int): Time-to-live. Maximum age of read value in seconds.
+
+        Returns:
+            Msg: Message
+
         Raises:
             ValueError: on decoder error
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed
+            EbusdShutdown: On EBUSD shutdown.
         """
         _LOGGER.info(f"read({msgdef!r}, ttl={ttl!r})")
         return await self._async_read(msgdef, ttl)
 
     async def async_write(self, msgdef, value, ttl=0):
-        """Write Message."""
+        """
+        Write Message.
+
+        If `msgdef` just contains a subset of fields, the `value` is applied only to these, by
+        running a read-modify-write operation.
+
+        Args:
+            msgdef (MsgDef): Message Definition
+
+        Keyword Args:
+            ttl (int): Time-to-live. Maximum age of read value in seconds.
+                       Just needed in case of a Read-Modify-Write.
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+        """
         _LOGGER.info(f"write({msgdef!r}, value={value!r}, ttl={ttl!r})")
         if not msgdef.write:
             raise ValueError(f"Message is not writeable '{msgdef}'")
@@ -169,17 +232,43 @@ class Ebus:
             raise CommandError(resp)
 
     async def async_listen(self, msgdefs=None):
-        """Listen to EBUSD, decode and yield."""
+        """
+        Listen to EBUS for messages.
+
+        Listen to automatically updated messages and EBUSDs polling mechanism.
+        Use :any:`async_setprio()` to set the EBUSD polling priority.
+
+        Keyword Args:
+            msgdefs (MsgDefs): Message definitions to be listened, other messages are ignored.
+
+        Yields:
+            Msg: Messages
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed
+            EbusdShutdown: On EBUSD shutdown.
+        """
         _LOGGER.info(f"listen(msgdefs={msgdefs!r})")
         async for msg in self._async_listen(msgdefs):
             yield msg
 
     async def async_setprio(self, msgdef, setprio=None):
         """
-        Read Message.
+        Set EBUSD message poll priority.
+
+        Args:
+            msgdef (MsgDef): Message definition
+
+        Keyword Args:
+            setprio: Priority `1-9` or `A` for automatic.
 
         Raises:
-            ValueError: on decoder error
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed
+            EbusdShutdown: On EBUSD shutdown.
         """
         _LOGGER.info(f"async_setprio({msgdef!r}, setprio={setprio!r})")
         msgdef = msgdef.replace(setprio=resolve_prio(msgdef, setprio or msgdef.setprio))
@@ -187,9 +276,23 @@ class Ebus:
 
     async def async_observe(self, msgdefs=None, ttl=None):
         """
-        Observe.
-
         Observe `msgdefs` messages.
+
+        Explicitly read all messages and then listen to automatically updated messages and
+        EBUSDs polling mechanism.
+        Use :any:`async_setprio()` to set the EBUSD polling priority.
+
+        Keyword Args:
+            msgdefs (MsgDefs): Message definitions to be observed, other messages are ignored.
+
+        Yields:
+            Msg: Message
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed
+            EbusdShutdown: On EBUSD shutdown.
         """
         _LOGGER.info(f"observe(msgdefs={msgdefs!r}, ttl={ttl!r})")
         msgdefs = msgdefs or self.msgdefs
@@ -224,7 +327,14 @@ class Ebus:
             yield msg
 
     async def async_get_state(self):
-        """Return state string."""
+        """
+        Return state string.
+
+        This method does **NOT** raise any exception.
+
+        Returns:
+            str: OK or any error value.
+        """
         _LOGGER.info("get_state()")
         return await self._async_get_state()
 
@@ -236,17 +346,31 @@ class Ebus:
                 return OK
             else:
                 return state
-        except (ConnectionError, CommandError):
+        except (ConnectionError, CommandError, ConnectionRefusedError):
             return "no ebusd connection"
 
     async def async_is_online(self):
-        """Return if we are online."""
+        """
+        Return `True` if everything is fine.
+
+        This method does **NOT** raise any exception.
+
+        Returns:
+            bool
+        """
         _LOGGER.info("is_online()")
         state = await self._async_get_state()
         return state == OK
 
     async def async_get_info(self):
-        """Return info dict."""
+        """
+        Return EBUSD meta information.
+
+        Returns
+            dict: Meta information according to metainfo_
+
+        .. _metainfo: https://github.com/john30/ebusd/wiki/3.1.-TCP-client-commands#info
+        """
         _LOGGER.info("get_info()")
         info = {}
         await self.connection.async_request("info")
@@ -256,7 +380,27 @@ class Ebus:
         return info
 
     async def async_cmd(self, cmd, infinite=False, check=False):
-        """Send `cmd` to EBUSD and Receive Response."""
+        """
+        Send EBUS_Command_ `cmd` to EBUSD and Receive Response.
+
+        .. _EBUS_Command: https://github.com/john30/ebusd/wiki/3.1.-TCP-client-commands
+
+        Args:
+            cmd (str): Commmand String
+
+        Keyword Args:
+            infinite (bool): Do not stop at first empty line.
+            check (bool): Abort on `ERR:` string in response.
+
+        Yields:
+            str: response
+
+        Raises:
+            ConnectionRefusedError: If connection cannot be established
+            ConnectionError: If not connected (`autoconnect==False`)
+            CommandError: If command failed and `check==True`.
+            EbusdShutdown: On EBUSD shutdown.
+        """
         _LOGGER.info(f"cmd({cmd!r}, infinite={infinite!r}, check={check!r})")
         await self.connection.async_write(cmd)
         async for line in self.connection.async_read(infinite=infinite, check=check):
