@@ -3,7 +3,11 @@ from . import types
 
 
 def get_icon(fielddef, state=None):
-    """Get Default Icon for `fielddef`."""
+    """
+    Return Appropriate mdi-icon_ for `fielddef` at `state`.
+
+    .. _mdi-icon: https://materialdesignicons.com/
+    """
     type_ = fielddef.type_
     if fielddef.unit in ("°C", "K", "°F"):
         return "mdi:thermometer"
