@@ -4,12 +4,14 @@ import collections
 from .const import NA
 from .util import repr_
 
-Error = collections.namedtuple("Error", "msg")
-
 
 class Msg(collections.namedtuple("_Msg", "msgdef fields")):
 
-    """Message With Fields."""
+    """
+    Message with Fields.
+
+    The message knows its definition and its fields.
+    """
 
     __slots__ = tuple()
 
@@ -27,7 +29,11 @@ class Msg(collections.namedtuple("_Msg", "msgdef fields")):
 
 class Field(collections.namedtuple("_Field", "fielddef value")):
 
-    """Field with Data."""
+    """
+    Field with Data.
+
+    The field knows its defintion and have one value.
+    """
 
     __slots__ = tuple()
 
@@ -51,7 +57,7 @@ class Field(collections.namedtuple("_Field", "fielddef value")):
 
 
 def filter_msg(msg=None, msgdefs=None):
-    """Strip Down Message to `msgdefs`."""
+    """Strip Down Message according to `msgdefs`."""
     if msg is not None:
         ident = msg.msgdef.ident
         if msgdefs is not None:
@@ -78,12 +84,17 @@ class BrokenMsg:
     """
     Broken Message.
 
-    .. note: In a boolean context this instance evaluates to `False`.
+    A broken message failed during decoding of EBUSD or the :any:`MsgDecoder`.
     """
 
     valid = False
 
     def __init__(self, msgdef, error):
+        """
+        Broken Message.
+
+        .. note: In a boolean context this instance evaluates to `False`.
+        """
         self.msgdef = msgdef
         self.error = error
 
