@@ -15,16 +15,52 @@ class MsgDef(_MsgDef, NodeMixin):
     """
     Message Definition.
 
+    A message is defined by `circuit` and `name` and has a fields
+
     Args:
         circuit (str): Circuit Name
         name (str): Message Name
-        children (tuple): Fields
+        children (tuple): Field definitions. :any:`FieldDef` and :any:`VirtFieldDef`.
 
     Keyword Args:
         read (bool): Message intend to be read
-        prio (int): Message Polling Priority
+        prio (int): Message Polling Priority on bus.
         write (bool): Message intend to be written
         updated (bool): Message intent to be seen automatically on every value change
+        setprio: Message polling priority to be set. Integer `1-9 or `A` for automatic.
+
+    >>> from pyebus import MsgDef, types
+    >>> m = MsgDef('circuit', 'name', [
+    ...     FieldDef(0, 'temp', types.IntType(-127, 128)),
+    ...     FieldDef(1, 'name', types.StrType(10)),
+    ...     VirtFieldDef('virt', types.StrType(), lambda msg: f'{msg.name}: {msg.temp}'),
+    ... ], read=True)
+    >>> m  # doctest: +ELLIPSIS
+    MsgDef('circuit', 'name', (FieldDef(0, 'temp', IntType(... VirtFieldDef('virt', StrType())), read=True)
+    >>> m.ident
+    'circuit/name'
+    >>> m.children
+    (FieldDef(0, 'temp', IntType(-127, 128)), FieldDef(1, 'name', StrType(length=10)), VirtFieldDef('virt', StrType()))
+    >>> m.fields
+    (FieldDef(0, 'temp', IntType(-127, 128)), FieldDef(1, 'name', StrType(length=10)))
+    >>> m.virtfields
+    (VirtFieldDef('virt', StrType()),)
+    >>> m.access
+    'r----'
+
+    :any:`MsgDef`, :any:`FieldDef` and :any:`VirtFieldDef` form a tree structure
+
+    >>> from anytree import RenderTree
+    >>> print(RenderTree(m))  # doctest: +ELLIPSIS
+    MsgDef('circuit', 'name', (FieldDef(0, 'temp', IntType(-127, 128)),..., StrType())), read=True)
+    ├── FieldDef(0, 'temp', IntType(-127, 128))
+    ├── FieldDef(1, 'name', StrType(length=10))
+    └── VirtFieldDef('virt', StrType())
+
+    Similar object can be easily created by:
+
+    >>> m.replace(children=m.fields[1:2])
+    MsgDef('circuit', 'name', (FieldDef(1, 'name', StrType(length=10)),), read=True)
     """
 
     __slots__ = tuple()
@@ -90,7 +126,7 @@ class MsgDef(_MsgDef, NodeMixin):
 
     @property
     def virtfields(self):
-        """Generic Fields."""
+        """Calulated Fields."""
         return tuple(child for child in self.children if isinstance(child, VirtFieldDef))
 
     @property
@@ -99,8 +135,8 @@ class MsgDef(_MsgDef, NodeMixin):
         return f"{self.circuit}/{self.name}"
 
     @property
-    def type_(self):
-        """Message Type."""
+    def access(self):
+        """Message Access."""
         read = "r" if self.read else "-"
         write = "w" if self.write else "-"
         update = "u" if self.update else "-"
@@ -144,7 +180,7 @@ class AbstractFieldDef(_FieldDef, NodeMixin):
         name (str): Unique name (as `name` may be used multiple times by ebus)
         type_ (Type): Type
 
-    Keywords Args:
+    Keyword Args:
         unit (str): Unit of the field value
         comment (str): Comment.
     """
@@ -220,7 +256,32 @@ class VirtFieldDef(AbstractFieldDef):
 
 
 def resolve_prio(msgdef, setprio):
-    """Calculate best priority."""
+    """
+    Resolve priority specification.
+
+    Integer values are just passed through.
+
+    >>> resolve_prio(MsgDef('circuit', 'name', [], read=True), 1)
+    1
+    >>> resolve_prio(MsgDef('circuit', 'name', [], read=True), 9)
+    9
+
+    The AUTO option, sets read-only messages to prio 1.
+
+    >>> resolve_prio(MsgDef('circuit', 'name', [], read=True), AUTO)
+    1
+
+    All other readable messages get prio 2
+
+    >>> resolve_prio(MsgDef('circuit', 'name', [], read=True, write=True), AUTO)
+    2
+    >>> resolve_prio(MsgDef('circuit', 'name', [], read=True, update=True), AUTO)
+    2
+
+    Non-readable messages have no prio.
+
+    >>> resolve_prio(MsgDef('circuit', 'name', [], write=True), AUTO)
+    """
     if msgdef.read:
         if setprio == AUTO:
             # Prio is only available on read messages.
