@@ -4,8 +4,6 @@ import re
 
 from .util import repr_
 
-_RE_BIT = re.compile(r"\ABI\d(:(\d))?\Z")
-
 
 class Type:
     """Abstract Type."""
@@ -802,137 +800,6 @@ class PinType(Type):
         return ""
 
 
-TYPEMAP = {
-    # BDA       BCD date                      dd.mm.yyyy               day first, including weekday, Sunday=0x06
-    # BDA:3     BCD date                      dd.mm.yyyy               day first, excluding weekday
-    # HDA       hex date                      dd.mm.yyyy               day first, including weekday, Sunday=0x07
-    # HDA:3     hex date                      dd.mm.yyyy               day first, excluding weekday
-    # DAY       date in days                  dd.mm.yyyy               days since 01.01.1900
-    "BDA": DateType(),
-    "BDA:3": DateType(),
-    "HDA": DateType(),
-    "HDA:3": DateType(),
-    "DAY": DateType(),
-    # BTI       BCD time                      hh:mm:ss                 seconds first
-    # HTI       hex time                      hh:mm:ss                 hours first
-    # VTI       hex time                      hh:mm:ss                 seconds first
-    "BTI": TimeType(),
-    "HTI": TimeType(),
-    "VTI": TimeType(),
-    # BTM       BCD time                      hh:mm                    minutes first
-    # HTM       hex time                      hh:mm                    hours first
-    # VTM       hex time                      hh:mm                    minutes first
-    # MIN       time in minutes               hh:mm                    minutes since last midnight
-    # TTM       truncated time                hh:m0                    multiple of 10 minutes
-    # TTH       truncated time                hh:m0                    multiple of 30 minutes
-    # TTQ       truncated time                hh:mm                    multiple of 15 minutes
-    "BTM": HourMinuteType(),
-    "HTM": HourMinuteType(),
-    "VTM": HourMinuteType(),
-    "MIN": HourMinuteType(),
-    "TTM": HourMinuteType(minres=10),
-    "TTH": HourMinuteType(minres=30),
-    "TTQ": HourMinuteType(minres=15),
-    # BDY       weekday                       Mon...Sun                Sunday=0x06
-    # HDY       weekday                       Mon...Sun                Sunday=0x07
-    "BDY": WeekdayType(),
-    "HDY": WeekdayType(),
-    # BCD       unsigned BCD                  0...99
-    # BCD:2     unsigned BCD                  0...9999
-    # BCD:3     unsigned BCD                  0...999999
-    # BCD:4     unsigned BCD                  0...99999999
-    "BCD": IntType(0, 99),
-    "BCD:2": IntType(0, 9999),
-    "BCD:3": IntType(0, 999999),
-    "BCD:4": IntType(0, 99999999),
-    # TODO: HCD       unsigned hex BCD              0...99999999             each BCD byte converted to hex
-    # TODO: HCD:1     unsigned hex BCD              0...99                   each BCD byte converted to hex
-    # TODO: HCD:2     unsigned hex BCD              0...9999                 each BCD byte converted to hex
-    # TODO: HCD:3     unsigned hex BCD              0...999999               each BCD byte converted to hex
-    # PIN       unsigned BCD                  0000...9999
-    "PIN": PinType(),
-    # UCH       unsigned integer              0...254
-    "UCH": IntType(0, 254),
-    # SCH       signed integer               -127...127
-    # D1B       signed integer               -127...127
-    "SCH": IntType(-127, 127),
-    "D1B": IntType(-127, 127),
-    # D1C       unsigned number               0.0...100.0              fraction 1/2 = divisor 2
-    "D1C": IntType(0, 100, divider=2),
-    # D2B       signed number                -127.99...127.99          fraction 1/256 = divisor 256
-    "D2B": IntType(-127.99, 127.99, divider=256),
-    # D2C       signed number                -2047.9...2047.9          fraction 1/16 = divisor 16
-    "D2C": IntType(-2047.9, 2047.9, divider=16),
-    # FLT       signed number                -32.767...32.767         low byte first, fraction 1/1000 = divisor 1000
-    # FLR       signed number reverse        -32.767...32.767         high byte first, fraction 1/1000 = divisor 1000
-    "FLT": IntType(-32.767, 32.767, divider=1000),
-    "FLR": IntType(-32.767, 32.767, divider=1000),
-    # EXP       signed float number          -3.0e38...3.0e38          low byte first
-    # EXR       signed float number reverse  -3.0e38...3.0e38          high byte first
-    "EXP": FloatType(),
-    "EXR": FloatType(),
-    # UIN       unsigned integer              0...65534                low byte first
-    # UIR       unsigned integer reverse      0...65534                high byte first
-    "UIN": IntType(0, 65534),
-    "UIR": IntType(0, 65534),
-    # SIN       signed integer               -32767...32767            low byte first
-    # SIR       signed integer reverse       -32767...32767            high byte first
-    "SIN": IntType(-32767, 32767),
-    "SIR": IntType(-32767, 32767),
-    # U3N       unsigned 3 byte int           0...16777214             low byte first
-    # U3R       unsigned 3 byte int reverse   0...16777214             high byte first
-    "U3N": IntType(0, 16777214),
-    "U3R": IntType(0, 16777214),
-    # S3N       signed 3 byte int            -8388607...8388607        low byte first
-    # S3R       signed 3 byte int reverse    -8388607...8388607        high byte first
-    "S3N": IntType(-8388607, 8388607),
-    "S3R": IntType(-8388607, 8388607),
-    # ULG       unsigned integer              0...4294967294           low byte first
-    # ULR       unsigned integer reverse      0...4294967294           high byte first
-    "ULG": IntType(0, 4294967294),
-    "ULR": IntType(0, 4294967294),
-    # SLG       signed integer               -2147483647...2147483647  low byte first
-    # SLR       signed integer reverse       -2147483647...2147483647  high byte first
-    "SLG": IntType(-2147483647, 2147483647),
-    "SLR": IntType(-2147483647, 2147483647),
-}
-
-
-def gettype(name, divider=None):
-    """Get :any:`Type` instance for `name` with `divider`."""
-    # create missing types
-    if name not in TYPEMAP:
-        # STR       character string              Hello
-        # NTS       character string              Hello
-        if name.startswith(("STR:", "NTS:")):
-            len_ = name.split(":")[1]
-            if len_ != "*":
-                TYPEMAP[name] = StrType(int(len_))
-            else:
-                TYPEMAP[name] = StrType()
-        # HEX       hex digit string              hex octet sep by space
-        if name.startswith("HEX:"):
-            len_ = name.split(":")[1]
-            if len_ != "*":
-                TYPEMAP[name] = HexType(int(len_))
-            else:
-                TYPEMAP[name] = HexType()
-        # BI0:7     bit 0                         0...1
-        mat = _RE_BIT.match(name)
-        if mat:
-            width = int(mat.groups()[1])
-            if width > 1:
-                TYPEMAP[name] = IntType(0, 2 ** width - 1)
-            else:
-                TYPEMAP[name] = BoolType()
-    # get type
-    type_ = TYPEMAP[name]
-    # divider
-    if divider:
-        type_ = type_.with_divider(divider)
-    return type_
-
-
 class Time(datetime.time):
 
     """Time."""
